@@ -2,7 +2,7 @@ package Pcore::API::DockerHub::Repository::Tag;
 
 use Pcore -class;
 
-extends qw[Pcore::API::Response];
+with qw[Pcore::Util::Result::Status];
 
 has repo => ( is => 'ro', isa => InstanceOf ['Pcore::API::DockerHub::Repository'], required => 1 );
 has id           => ( is => 'ro', isa => Int, required => 1 );
