@@ -4,11 +4,11 @@ use Pcore -class;
 
 with qw[Pcore::Dist::CLI];
 
-sub cli_abstract ($self) {
-    return 'update README.md and LICENSE';
+sub CLI ($self) {
+    return { abstract => 'update README.md and LICENSE', };
 }
 
-sub cli_run ( $self, $opt, $arg, $rest ) {
+sub CLI_RUN ( $self, $opt, $arg, $rest ) {
     $self->new->run;
 
     return;
