@@ -431,6 +431,11 @@ sub _get_mime_types ($self) {
                 $MIME_TYPES->{category}->{$type} = $1;
             }
         }
+
+        # compile shebang
+        for my $key ( keys $MIME_TYPES->{shebang}->%* ) {
+            $MIME_TYPES->{shebang}->{$key} = qr/$MIME_TYPES->{shebang}->{$key}/sm;
+        }
     }
 
     return $MIME_TYPES;
@@ -468,8 +473,6 @@ sub TO_DUMP {
 ## |    3 | 1                    | Modules::ProhibitExcessMainComplexity - Main code has high complexity score (58)                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 | 19                   | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 363                  | ValuesAndExpressions::ProhibitNoisyQuotes - Quotes used with a noisy string                                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
